Request for Comments (RFCs)
===========================

What is a RFC?
--------------

.. warning:: TODO: Better describe our RFC model here.

Submiting a RFC
---------------

.. warning:: TODO: Better describe our RFC model here.

Previous RFCs
-------------

The following list contains archivals of accepted, Request For Comments posted
and discussed on the `Avocado Devel Mailing List`_.

.. toctree::
   :maxdepth: 1

   ../rfcs/lts

.. _Avocado Devel Mailing List: https://www.redhat.com/mailman/listinfo/avocado-devel

